pub struct StandardTextPairBlock {
pub label: Option<Box<TextComponent>>,
pub description: Option<Box<TextComponent>>,
}Expand description
StandardTextPairBlock : The A+ Content standard label and description block, comprised of a pair of text components.
Fields
label: Option<Box<TextComponent>>description: Option<Box<TextComponent>>Implementations
sourceimpl StandardTextPairBlock
impl StandardTextPairBlock
sourcepub fn new() -> StandardTextPairBlock
pub fn new() -> StandardTextPairBlock
The A+ Content standard label and description block, comprised of a pair of text components.